@@ -24,7 +24,7 @@ namespace xsimd
     using duration_type = std::chrono::duration<double, std::milli>;
 
     template <class T>
-    using bench_vector = std::vector<T, xsimd::aligned_allocator<T>>;
+    using bench_vector = std::vector<T, xsimd::aligned_allocator<T, default_arch::alignment()>>;
 
     template <class T>
     void init_benchmark(bench_vector<T>& lhs, bench_vector<T>& rhs, bench_vector<T>& res, size_t size)
@@ -382,7 +382,7 @@ namespace xsimd
 #endif
 
         out << "============================" << std::endl;
-        out << default_arch::name() << std::endl;
+        out << f.name() << std::endl;
         out << "scalar float      : " << t_float_scalar.count() << "ms" << std::endl;
         out << "vector float      : " << t_float_vector.count() << "ms" << std::endl;
         out << "vector float unr  : " << t_float_vector_u.count() << "ms" << std::endl;
@@ -413,7 +413,7 @@ namespace xsimd
 #endif
 
         out << "============================" << std::endl;
-        out << default_arch::name() << std::endl;
+        out << f.name() << std::endl;
         out << "scalar float      : " << t_float_scalar.count() << "ms" << std::endl;
         out << "vector float      : " << t_float_vector.count() << "ms" << std::endl;
         out << "vector float unr  : " << t_float_vector_u.count() << "ms" << std::endl;
