@@ -14,18 +14,16 @@
 
 #include "test_utils.hpp"
 
-#include <cfenv>
-
 template <class B>
-class power_test : public testing::Test
+struct power_test
 {
-protected:
     using batch_type = B;
     using value_type = typename B::value_type;
     static constexpr size_t size = B::size;
     using vector_type = std::vector<value_type>;
 
     size_t nb_input;
+    vector_type zero_input;
     vector_type zlhs_input;
     vector_type lhs_input;
     vector_type rhs_input;
@@ -35,11 +33,13 @@ protected:
     power_test()
     {
         nb_input = size * 10000;
+        zero_input.resize(nb_input);
         zlhs_input.resize(nb_input);
         lhs_input.resize(nb_input);
         rhs_input.resize(nb_input);
         for (size_t i = 0; i < nb_input; ++i)
         {
+            zero_input[i] = 0;
             lhs_input[i] = value_type(i) / 4 + value_type(1.2) * std::sqrt(value_type(i + 0.25));
             zlhs_input[i] = lhs_input[i] * (i % 2);
             rhs_input[i] = value_type(10.2) / (i + 2) + value_type(0.25);
@@ -65,7 +65,8 @@ protected:
                 detail::store_batch(out, res, i);
             }
             size_t diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("pow");
+            INFO("pow");
+            CHECK_EQ(diff, 0);
         }
         // pow zero
         {
@@ -81,9 +82,11 @@ protected:
                 detail::store_batch(out, res, i);
             }
             size_t diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("pow");
+            INFO("0 ^ x");
+            CHECK_EQ(diff, 0);
 
-#ifdef __SSE__
+// use of undeclared identifier '_MM_SET_EXCEPTION_MASK for emscripten
+#if defined(__SSE__) && !defined(EMSCRIPTEN)
             // Test with FE_INVALID...
             unsigned mask = _MM_GET_EXCEPTION_MASK();
             _MM_SET_EXCEPTION_MASK(mask & ~_MM_MASK_INVALID);
@@ -96,9 +99,27 @@ protected:
             }
             _MM_SET_EXCEPTION_MASK(mask);
             diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("pow");
+            INFO("0 ^ x with exception");
+            CHECK_EQ(diff, 0);
 #endif
         }
+        // pow 0^-x
+        {
+            std::transform(zero_input.cbegin(), zero_input.cend(), rhs_input.cbegin(), expected.begin(),
+                           [](const value_type& z, const value_type& r)
+                           { return std::pow(z, -r); });
+            batch_type zero_in, rhs_in, out;
+            for (size_t i = 0; i < nb_input; i += size)
+            {
+                detail::load_batch(zero_in, zero_input, i);
+                detail::load_batch(rhs_in, rhs_input, i);
+                out = pow(zero_in, -rhs_in);
+                detail::store_batch(out, res, i);
+            }
+            size_t diff = detail::get_nb_diff(res, expected);
+            INFO("pow(0, -x)");
+            CHECK_EQ(diff, 0);
+        }
         // ipow
         {
             long k = 0;
@@ -113,7 +134,8 @@ protected:
                 detail::store_batch(out, res, i);
             }
             size_t diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("ipow");
+            INFO("ipow");
+            CHECK_EQ(diff, 0);
         }
         // hypot
         {
@@ -129,7 +151,8 @@ protected:
                 detail::store_batch(out, res, i);
             }
             size_t diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("hypot");
+            INFO("hypot");
+            CHECK_EQ(diff, 0);
         }
         // cbrt
         {
@@ -144,15 +167,15 @@ protected:
                 detail::store_batch(out, res, i);
             }
             size_t diff = detail::get_nb_diff(res, expected);
-            EXPECT_EQ(diff, 0) << print_function_name("cbrt");
+            INFO("cbrt");
+            CHECK_EQ(diff, 0);
         }
     }
 };
 
-TYPED_TEST_SUITE(power_test, batch_float_types, simd_test_names);
-
-TYPED_TEST(power_test, power)
+TEST_CASE_TEMPLATE("[power]", B, BATCH_FLOAT_TYPES)
 {
-    this->test_power_functions();
+    power_test<B> Test;
+    Test.test_power_functions();
 }
 #endif
